"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var hz_date_picker_service_1 = require("./hz-date-picker.service");
var HZDatePickerComponent = (function () {
    function HZDatePickerComponent(dpService) {
        this.dpService = dpService;
        this.onDateChange = new core_1.EventEmitter();
        this.viewLoaded = false;
        this.isCallInProgress = false;
        this.selectedDate = new Date();
        this.MONTH_NAVS = {
            NEXT: 'next',
            PREV: 'previous'
        };
        this.validDayFormats = ["E", "EEE", "EEEE"];
    }
    HZDatePickerComponent.prototype.ngOnInit = function () {
    };
    HZDatePickerComponent.prototype.ngAfterViewInit = function () {
        this.updateDateBtns();
        this.setDefaultConfigValues();
        this.viewLoaded = true;
    };
    /**
     * @author Ahsan Ayaz
     * Sets the inital config properties to be used by the datepicker template
     */
    HZDatePickerComponent.prototype.setDefaultConfigValues = function () {
        this.dpConfig = this.dpConfig || {};
        this.dpConfig.dayFormat = this.dpConfig.dayFormat ? this.dpConfig.dayFormat : 'E';
        if (this.validDayFormats.indexOf(this.dpConfig.dayFormat) == -1) {
            throw new Error("Invalid day format in dpConfig, supported formats are = " + this.validDayFormats.join());
        }
        this.dpConfig.selectedDateFormat = this.dpConfig.selectedDateFormat ? this.dpConfig.selectedDateFormat : 'fullDate';
        this.dpConfig.selectedItemClass = this.dpConfig.selectedItemClass ? this.dpConfig.selectedItemClass + ' selected' : 'selected';
    };
    /**
     * @author Ahsan Ayaz
     * This function is triggered when a date is clicked from the dates list
     * @param dayBtn
     */
    HZDatePickerComponent.prototype.onDateClick = function (dayBtn) {
        this.daysOfMonth.forEach(function (btn) {
            btn.isSelected = false;
        });
        dayBtn.isSelected = true;
        this.selectedDate = dayBtn.date;
        this.onDateChange.emit(this.selectedDate);
    };
    /**
     * @author Ahsan Ayaz
     * This function updates the buttons to display using the current date
     * @param date
     */
    HZDatePickerComponent.prototype.updateDateBtns = function (date) {
        var _this = this;
        this.daysOfMonth = this.dpService.getDaysOfMonth(date);
        this.isCallInProgress = true;
        setTimeout(function () {
            _this.isCallInProgress = false;
        }, 1500);
    };
    /**
     * @author Ahsan Ayaz
     * This function is triggered when the user clicks on any of the next month nav button or previous month nav button
     * Fetches the next month's buttons from service and updates the buttons on view.
     * Also sets the same date of the next month as selected date
     * @param target
     */
    HZDatePickerComponent.prototype.onMonthNavClick = function (target) {
        var targetMonth = (target == this.MONTH_NAVS.NEXT) ? this.selectedDate.getMonth() + 1 : this.selectedDate.getMonth() - 1;
        var dateToSet = this.selectedDate.getDate();
        var targetMonthDaysCount = this.dpService.daysInMonth(null, this.selectedDate.getFullYear(), targetMonth);
        if (dateToSet > targetMonthDaysCount) {
            dateToSet = targetMonthDaysCount;
        }
        var neededDate = new Date(this.selectedDate.getFullYear(), targetMonth, dateToSet);
        this.updateDateBtns(neededDate);
        this.selectedDate = this.daysOfMonth[neededDate.getDate() - 1].date;
        this.onDateChange.emit(this.selectedDate);
    };
    return HZDatePickerComponent;
}());
__decorate([
    core_1.ViewChild('hzDatePicker'),
    __metadata("design:type", core_1.ElementRef)
], HZDatePickerComponent.prototype, "hzDatePicker", void 0);
__decorate([
    core_1.Input('dpConfig'),
    __metadata("design:type", Object)
], HZDatePickerComponent.prototype, "dpConfig", void 0);
__decorate([
    core_1.Output(),
    __metadata("design:type", core_1.EventEmitter)
], HZDatePickerComponent.prototype, "onDateChange", void 0);
HZDatePickerComponent = __decorate([
    core_1.Component({
        selector: 'hz-date-picker',
        template: "\n    <div #hzDatePicker class=\"hz-datepicker-container\"  *ngIf=\"viewLoaded\">\n      <div class=\"hz-datepicker-inner\">\n          <div class=\"days\">\n              <div class=\"days-prev\">\n                  <button class=\"dp-button dp-button-prev {{dpConfig.navBtnClasses}}\" (click)=\"onMonthNavClick(MONTH_NAVS.PREV)\"><<</button>\n              </div>\n              <div class=\"days-inner\">\n                  <div *ngFor=\"let btn of daysOfMonth\" class=\"day-item\">\n                      <div [style.display]=\"dpConfig.showDays? 'block' : 'none'\" class=\"weekday\" [ngClass]=\"{'is-weekend': btn.isWeekend}\">\n                          {{btn.date | date: dpConfig.dayFormat}}\n                      </div>\n                      <button \n                          class=\"dp-button dp-button-day {{dpConfig.btnClasses}} {{btn.isSelected? dpConfig.selectedItemClass : ''}}\"\n                          (click)=\"onDateClick(btn)\">\n                          {{btn.text}}\n                      </button>\n                  </div>\n                  \n              </div>\n              <div class=\"days-next\">\n                  <button class=\"dp-button dp-button-next {{dpConfig.navBtnClasses}}\" (click)=\"onMonthNavClick(MONTH_NAVS.NEXT)\">>></button>\n              </div>\n          </div>\n          <h4 class=\"text-center selected-date\">\n              {{selectedDate | date : dpConfig.selectedDateFormat}}\n          </h4>\n      </div>\n  </div>\n  ",
        styleUrls: ['hz-date-picker.component.scss']
    }),
    __metadata("design:paramtypes", [hz_date_picker_service_1.HZDatePickerService])
], HZDatePickerComponent);
exports.HZDatePickerComponent = HZDatePickerComponent;
//# sourceMappingURL=hz-date-picker.component.js.map